import es, cfglib, cmdlib, gamethread, langlib, playerlib, popuplib, usermsg

info = es.AddonInfo()
info.name = 'LooneyRadio'
info.basename = info.name.lower()
info.version = '1.0'
info.url = 'http://addons.eventscripts.com/addons/view/LooneyRadio'
info.author = 'Satoon101'
es.ServerVar('%s_version'%info.basename,info.version,'%s Version'%info.name).makepublic()

addonpath = es.getAddonPath(info.basename)
config = cfglib.AddonCFG(addonpath + '/lr_config.cfg')
lr_command = config.cvar('lr_command','!radio','Command to bring up Radio Station Menu')
lr_announce_command = config.cvar('lr_announce_command',1,'0 = No Announcement, 1 = Announce by Rounds, 2 = Announce by Time')
lr_announce_amount = config.cvar('lr_announce_amount',3,'Amount of Rounds/Minutes between announcements')
config.write()

ini = cfglib.AddonINI(addonpath + '/strings.ini')
ini_strings = [
    ['Announce',['en','#green[LooneyRadio]#default To listen to the Radio, or to change stations, type "#lightgreen$command#default"'],],
    ['MainMenu',['en','Choose a Style of Music:'],],
    ['RadioMenu',['en','Choose a Station from $station_type:'],],
    ['Choice',['en','#green[LooneyRadio]#default You chose#lightgreen $station'],],
              ]
ini.setInitialComments([])
for group in ini_strings:
    header = group[0]
    for amount in range(1,len(group)):
        ini.addValueToGroup(header,group[amount][0],group[amount][1])
    ini.setGroupComments(header,[])
ini.write()
lr_lang = langlib.Strings(ini)

stations = cfglib.AddonINI(addonpath + '/stations.ini')
stations_comments = [
    'Place all Station types and their station urls in this file',
    'This script does not come with any stations included, so you need to find and write in your own',
    'The following is just an example and will not actually work',
    'Delete them after you understand the syntax',
    'Make sure to use Unique styles and station names',
    'Doubling any can cause an error in the script',
                    ]
stations.setInitialComments(stations_comments)
if not len(stations):
    stations.addValueToGroup('Country','Top 100 Country','http://www.mystations.com/top100_country.html')
    stations.addValueToGroup('Country','New Age Country','http://www.mystations.com/newage_country.html')
    stations.addValueToGroup('Rock & Roll','Old Time R&R','http://www.mystations.com/oldtime_rockandroll.html')
    stations.addValueToGroup('Rock & Roll','Classic R&R','http://www.mystations.com/classic_rockandroll.html')
stations.write()

PlayerList = {}

class Player:
    def __init__(self,userid):
        self.userid = userid
        self.lang = playerlib.getPlayer(self.userid).lang
    
    def sendMainMenu(self):
        mainmenu = popuplib.easymenu(lr_lang('MainMenu',lang=self.lang),'choice',self.chosenStyle)
        for style in stations:
            mainmenu.addoption(style,style)
        mainmenu.send(self.userid)
    
    def chosenStyle(self,userid,style,popupid):
        stationmenu = popuplib.easymenu(lr_lang('RadioMenu',{'station_type':style},self.lang),'choice',self.chosenStation)
        for station in stations[style]:
            stationmenu.addoption((station,style),station)
        stationmenu.send(self.userid)
    
    def chosenStation(self,userid,(station,style),popupid):
        es.tell(self.userid,'#multi',lr_lang('Choice',{'station':station},self.lang))
        usermsg.motd(self.userid,2,station,stations[style][station],False)
    
    def sendPlayerAnnouncement(self):
        es.tell(self.userid,'#multi',lr_lang('Announce',{'command':announce.command},self.lang))

class AnnounceManagement:
    rounds = 0
    
    def loadAnnounce(self):
        self.command = str(lr_command)
        self.startAnnounce()
    
    def startAnnounce(self):
        self.rounds = 0
        gamethread.cancelDelayed('lr_Announce')
        if lr_announce_command == 2:
            gamethread.delayedname(lr_announce_amount * 60,'lr_Announce',self.sendAnnouncement)
    
    def roundStart(self):
        if lr_announce_command != 1: return
        self.rounds += 1
        if self.rounds >= lr_announce_amount:
            self.rounds = 0
            self.sendAnnouncement()
    
    def sendAnnouncement(self):
        if lr_announce_command == 2:
            gamethread.delayedname(lr_announce_amount * 60,'lr_Announce',self.sendAnnouncement)
        for userid in playerlib.getUseridList('#human'):
            getUser(userid).sendPlayerAnnouncement()

announce = AnnounceManagement()

def getUser(userid):
    userid = str(userid)
    if not userid in PlayerList:
        PlayerList[userid] = Player(userid)
    return PlayerList[userid]

def load():
    config.execute()
    announce.loadAnnounce()
    cmdlib.registerSayCommand(announce.command,sendRadioMenu,'Send the Radio Menu')
    cmdlib.registerClientCommand(announce.command,sendRadioMenu,'Send the Radio Menu')

def es_map_start(ev):
    announce.startAnnounce()

def unload():
    cmdlib.unregisterSayCommand(announce.command)
    cmdlib.unregisterClientCommand(announce.command)

def round_start(ev):
    announce.roundStart()

def sendRadioMenu(userid,args):
    getUser(userid).sendMainMenu()